==> manydhcp2.5.2.tar.bz2: manydhcp/srvset/index.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['menu-btn36-title'];
  if(!isset($button)) $button = $TEXT['btn_save'];
  if(!isset($action)) $action = "edit.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $query_iskh4 = "SELECT * FROM `tbl_srvparam` LIMIT 1";
  $result_iskh4 = mysql_query($query_iskh4);
  if(!$result_iskh4) {puterror($result2['skin'],$TEXT['error-tbl14']); require_once "../utils/bottom_adm.php"; exit();}
   $result_iskh_many = mysql_fetch_array($result_iskh4,MYSQL_ASSOC);

?>
<table align="center" class="table" border="0" cellpadding="0" cellspacing="0" width="30%">
<tr>
 <td class="upd"><?php echo $TEXT['srvpar-help']; ?></td>
</tr>
</table>
<br />
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" border="0" width="30%">
 <tr><td>
<table align="left" >
<tr><td class="bold_it_page"><?php echo $TEXT['menu-btn34-title']; ?></td><td>
 <select name=sams>
   <option value='0' <?php if ($result_iskh_many['sams'] == "0") echo "selected"?>><?php echo $TEXT['srvpar-vikl']; ?>
   <option value='1' <?php if ($result_iskh_many['sams'] == "1") echo "selected"?>><?php echo $TEXT['srvpar-vkl']; ?>
 </select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srvpar-pass']; ?></td><td><input size=5 maxlength=5 type=text name=usrpass value='<?php echo $result_iskh_many['usrpass']; ?>'></td></tr>
<tr><td>&nbsp;</td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
</table>
</td>
</tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/srvset/index.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['menu-btn36-title'];
  $button = $TEXT['btn_save'];
  $action = "edit.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $query_iskh4 = "SELECT * FROM `tbl_srvparam` LIMIT 1";
  $result_iskh4 = mysqli_query($dbcnx,$query_iskh4);
  if(!$result_iskh4) {puterror($result2['skin'],$TEXT['error-tbl14']); require_once "../utils/bottom_adm.php"; exit();}
   $result_iskh_many = mysqli_fetch_array($result_iskh4,MYSQLI_ASSOC);

?>
<table align="center" class="table" border="0" cellpadding="0" cellspacing="0" width="30%">
<tr>
 <td class="upd"><?php echo $TEXT['srvpar-help']; ?></td>
</tr>
</table>
<br />
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" border="0" width="30%">
 <tr><td>
<table align="left" >
<tr><td class="bold_it_page"><?php echo $TEXT['menu-btn34-title']; ?></td><td>
 <select name=sams>
   <option value='0' <?php if ($result_iskh_many['sams'] == "0") {echo "selected";} ?>><?php echo $TEXT['srvpar-vikl']; ?>
   <option value='1' <?php if ($result_iskh_many['sams'] == "1") {echo "selected";} ?>><?php echo $TEXT['srvpar-vkl']; ?>
 </select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srvpar-pass']; ?></td><td><input size=5 maxlength=5 type=text name=usrpass value='<?php echo $result_iskh_many['usrpass']; ?>'></td></tr>
<tr><td>&nbsp;</td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
</table>
</td>
</tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
